git: 517b01349920 - main - www/chromium: update to 138.0.7204.96
- Go to: [ bottom of page ] [ top of archives ] [ this month ]
Date: Wed, 02 Jul 2025 12:54:50 UTC
The branch main has been updated by rnagy:
URL: https://cgit.FreeBSD.org/ports/commit/?id=517b01349920d28d9b4484ea83ab10eecbe0889a
commit 517b01349920d28d9b4484ea83ab10eecbe0889a
Author: Robert Nagy <rnagy@FreeBSD.org>
AuthorDate: 2025-07-02 12:47:18 +0000
Commit: Robert Nagy <rnagy@FreeBSD.org>
CommitDate: 2025-07-02 12:54:37 +0000
www/chromium: update to 138.0.7204.96
Security: https://vuxml.freebsd.org/freebsd/5c777f88-40ff-4e1e-884b-ad63dfb9bb15.html
Security: https://vuxml.freebsd.org/freebsd/9c91e1f8-f255-4b57-babe-2e385558f1dc.html
---
www/chromium/Makefile | 3 +-
www/chromium/distinfo | 10 +-
www/chromium/files/patch-BUILD.gn | 18 +--
www/chromium/files/patch-base_BUILD.gn | 22 ++--
...cator_partition__allocator_partition__alloc.gni | 6 +-
...tition__allocator_src_partition__alloc_BUILD.gn | 4 +-
...rtition__alloc__base_debug_proc__maps__linux.cc | 4 +-
...src_partition__alloc_partition__alloc__config.h | 6 +-
..._partition__alloc_partition__alloc__constants.h | 6 +-
...rc_partition__alloc_partition__alloc__forward.h | 10 +-
...locator_src_partition__alloc_partition__root.cc | 4 +-
www/chromium/files/patch-base_compiler__specific.h | 4 +-
.../files/patch-base_debug_debugger__posix.cc | 6 +-
...-base_memory_platform__shared__memory__region.h | 26 ++---
...mory_platform__shared__memory__region__posix.cc | 6 +-
.../files/patch-base_process_internal__linux.h | 6 +-
.../files/patch-base_process_process__posix.cc | 10 +-
...ch-base_threading_platform__thread__unittest.cc | 15 +--
...tch-base_trace__event_malloc__dump__provider.cc | 4 +-
.../files/patch-build_config_BUILDCONFIG.gn | 12 +-
.../files/patch-build_config_clang_BUILD.gn | 4 +-
.../files/patch-build_config_compiler_BUILD.gn | 46 +++++---
www/chromium/files/patch-build_config_rust.gni | 10 +-
.../files/patch-build_toolchain_toolchain.gni | 4 +-
.../patch-chrome_app_chrome__main__delegate.cc | 28 ++---
www/chromium/files/patch-chrome_browser_BUILD.gn | 4 +-
.../files/patch-chrome_browser_about__flags.cc | 119 ++++++++++++--------
.../patch-chrome_browser_browser__features.cc | 4 +-
.../files/patch-chrome_browser_browser__features.h | 4 +-
.../patch-chrome_browser_browser__process__impl.cc | 12 +-
..._browser_chrome__browser__interface__binders.cc | 6 +-
...r_chrome__browser__interface__binders__webui.cc | 10 +-
.../patch-chrome_browser_chrome__browser__main.cc | 14 +--
...ome_browser_chrome__content__browser__client.cc | 99 ++++------------
...rome_browser_chrome__content__browser__client.h | 4 +-
...tent__browser__client__navigation__throttles.cc | 38 +++++++
...rome_browser_component__updater_registration.cc | 8 +-
...download_chrome__download__manager__delegate.cc | 8 +-
...ser__management_browser__management__service.cc | 25 +++--
...wser__management_browser__management__service.h | 13 ++-
...er_enterprise_connectors_connectors__service.cc | 4 +-
...nnectors_reporting_crash__reporting__context.cc | 4 +-
...nectors_reporting_realtime__reporting__client.h | 6 +-
..._cloud__profile__reporting__service__factory.cc | 4 +-
...wser_enterprise_util_managed__browser__utils.cc | 15 ++-
.../files/patch-chrome_browser_extensions_BUILD.gn | 4 +-
...s_api_runtime_chrome__runtime__api__delegate.cc | 8 +-
...api_webstore__private_webstore__private__api.cc | 4 +-
...ck_system__logs_about__system__logs__fetcher.cc | 6 +-
...k_system__logs_chrome__system__logs__fetcher.cc | 6 +-
.../patch-chrome_browser_flag__descriptions.cc | 47 ++++----
.../patch-chrome_browser_flag__descriptions.h | 47 ++++----
.../files/patch-chrome_browser_global__features.cc | 8 +-
.../files/patch-chrome_browser_global__features.h | 10 +-
...chrome_browser_headless_headless__mode__util.cc | 8 +-
..._galleries_fileapi_mtp__device__map__service.cc | 4 +-
...dia__galleries_media__file__system__registry.cc | 4 +-
...e_browser_media_webrtc_webrtc__log__uploader.cc | 4 +-
...chrome__browser__main__extra__parts__metrics.cc | 6 +-
...ser_metrics_chrome__metrics__service__client.cc | 22 ++--
...hrome_browser_metrics_power_process__monitor.cc | 8 +-
...rowser_net_system__network__context__manager.cc | 30 ++---
...browser_net_system__network__context__manager.h | 4 +-
..._browser_new__tab__page_new__tab__page__util.cc | 4 +-
...d__manager_chrome__password__manager__client.cc | 24 +++-
...onfiguration__policy__handler__list__factory.cc | 125 ++++++---------------
.../patch-chrome_browser_prefs_browser__prefs.cc | 14 +--
...er_printing_print__backend__service__manager.cc | 20 ++--
...hrome__browser__main__extra__parts__profiles.cc | 24 ++--
.../patch-chrome_browser_profiles_profile__impl.cc | 8 +-
...ties_regional__capabilities__service__client.cc | 4 +-
...dent__reporting_incident__reporting__service.cc | 4 +-
...reen__ai_screen__ai__service__handler__base.cc} | 10 +-
...tch-chrome_browser_sessions_session__restore.cc | 4 +-
...__user_supervised__user__extensions__manager.cc | 6 +-
...d__user_supervised__user__extensions__manager.h | 4 +-
...me_browser_task__manager_sampling_task__group.h | 4 +-
...r_task__manager_sampling_task__manager__impl.cc | 4 +-
.../patch-chrome_browser_themes_theme__service.cc | 4 +-
...hrome_browser_themes_theme__service__factory.cc | 8 +-
...-chrome_browser_ui_actions_chrome__action__id.h | 4 +-
.../files/patch-chrome_browser_ui_browser.h | 4 +-
...rome_browser_ui_browser__command__controller.cc | 18 +--
.../patch-chrome_browser_ui_browser__commands.cc | 4 +-
.../patch-chrome_browser_ui_browser__ui__prefs.cc | 6 +-
.../files/patch-chrome_browser_ui_chrome__pages.cc | 8 +-
.../files/patch-chrome_browser_ui_chrome__pages.h | 4 +-
...e_browser_ui_signin_signin__view__controller.cc | 11 +-
...me_browser_ui_signin_signin__view__controller.h | 11 ++
..._ui_signin_signin__view__controller__delegate.h | 13 ++-
...browser_ui_startup_startup__browser__creator.cc | 8 +-
...me_browser_ui_startup_startup__tab__provider.cc | 6 +-
.../files/patch-chrome_browser_ui_tab__helpers.cc | 6 +-
.../files/patch-chrome_browser_ui_tabs_features.cc | 4 +-
.../patch-chrome_browser_ui_tabs_tab__features.cc | 4 +-
...ui_task__manager_task__manager__table__model.cc | 10 +-
...ch-chrome_browser_ui_test_popup__browsertest.cc | 6 +-
.../files/patch-chrome_browser_ui_ui__features.cc | 6 +-
.../files/patch-chrome_browser_ui_ui__features.h | 4 +-
...h-chrome_browser_ui_views_accelerator__table.cc | 8 +-
...-chrome_browser_ui_views_frame_browser__view.cc | 6 +-
...ui_views_new__tab__footer_footer__controller.cc | 11 ++
...rowser_ui_views_omnibox_omnibox__view__views.cc | 4 +-
...er_ui_views_profiles_avatar__toolbar__button.cc | 4 +-
...ser_ui_views_profiles_avatar__toolbar__button.h | 4 +-
...ui_views_profiles_profile__menu__coordinator.cc | 4 +-
...rowser_ui_views_profiles_profile__menu__view.cc | 13 ++-
..._ui_views_profiles_profile__menu__view__base.cc | 4 +-
...wser_ui_views_profiles_profile__picker__view.cc | 6 +-
...es_signin__view__controller__delegate__views.cc | 38 ++++++-
...les_signin__view__controller__delegate__views.h | 15 ++-
...ui_views_tabs_dragging_tab__drag__controller.cc | 12 +-
...wser_ui_views_tabs_tab__strip__combo__button.cc | 4 +-
...rome_browser_ui_views_tabs_tab__style__views.cc | 4 +-
..._education_browser__user__education__service.cc | 6 +-
...eb__apps_web__app__integration__test__driver.cc | 20 ++--
...eb__applications_web__app__ui__manager__impl.cc | 6 +-
...web__applications_web__app__ui__manager__impl.h | 4 +-
...atch-chrome_browser_ui_webui_about_about__ui.cc | 12 +-
...patch-chrome_browser_ui_webui_about_about__ui.h | 4 +-
..._ui_webui_app__home_app__home__page__handler.cc | 4 +-
...r_ui_webui_app__home_app__home__page__handler.h | 6 +-
...i_certificate__manager_client__cert__sources.cc | 4 +-
...me_browser_ui_webui_chrome__web__ui__configs.cc | 14 +--
...i_webui_chrome__web__ui__controller__factory.cc | 8 +-
...i_connectors__internals_device__trust__utils.cc | 6 +-
...wser_ui_webui_interstitials_interstitial__ui.cc | 6 +-
...r_ui_webui_management_management__ui__handler.h | 6 +-
...rowser_ui_webui_searchbox_searchbox__handler.cc | 8 +-
...tings_settings__localized__strings__provider.cc | 18 +--
...r__education__internals__page__handler__impl.cc | 4 +-
...hrome_browser_ui_window__sizer_window__sizer.cc | 4 +-
...s_commands_set__user__display__mode__command.cc | 4 +-
...pplications_policy_web__app__policy__manager.cc | 4 +-
...thn_chrome__authenticator__request__delegate.cc | 4 +-
...tch-chrome_browser_webauthn_enclave__manager.cc | 6 +-
.../files/patch-chrome_common_chrome__features.cc | 10 +-
.../files/patch-chrome_common_chrome__features.h | 8 +-
.../files/patch-chrome_common_chrome__switches.cc | 6 +-
.../files/patch-chrome_common_chrome__switches.h | 6 +-
...chrome_common_extensions_extension__constants.h | 4 +-
.../patch-chrome_common_media_cdm__registration.cc | 14 +--
.../files/patch-chrome_common_pref__names.h | 27 ++---
.../files/patch-chrome_common_url__constants.h | 4 +-
.../patch-chrome_common_webui__url__constants.h | 8 +-
...vices_printing_print__backend__service__impl.cc | 12 +-
...ch-chrome_test_chromedriver_chrome__launcher.cc | 4 +-
...e_test_chromedriver_key__converter__unittest.cc | 6 +-
.../patch-chrome_updater_app_app__uninstall.cc | 4 +-
.../files/patch-chrome_updater_configurator.cc | 4 +-
...hromecast_browser_cast__browser__main__parts.cc | 8 +-
www/chromium/files/patch-components_BUILD.gn | 8 +-
...ta__manager_payments_payments__data__manager.cc | 12 +-
...ata__manager_payments_payments__data__manager.h | 6 +-
...owser_foundations_browser__autofill__manager.cc | 4 +-
...browser_payments_amount__extraction__manager.cc | 26 ++---
...ebdata_payments_payments__sync__bridge__util.cc | 4 +-
...ill_core_common_autofill__payments__features.cc | 4 +-
...ponents_autofill_core_common_autofill__prefs.cc | 10 +-
...mponents_autofill_core_common_autofill__prefs.h | 6 +-
...onents_commerce_core_commerce__feature__list.cc | 10 +-
...nstrained__window_constrained__window__views.cc | 4 +-
...ctors_core_realtime__reporting__client__base.cc | 4 +-
...e__engagement_public_feature__configurations.cc | 4 +-
...eature__engagement_public_feature__constants.cc | 10 +-
...feature__engagement_public_feature__constants.h | 8 +-
...nts_feature__engagement_public_feature__list.cc | 10 +-
...ents_feature__engagement_public_feature__list.h | 16 +--
.../patch-components_feed_core_v2_proto__util.cc | 6 +-
...omponents_feed_core_v2_proto__util__unittest.cc | 4 +-
.../files/patch-components_metrics_metrics__log.cc | 10 +-
.../patch-components_os__crypt_sync_os__crypt.h | 18 +--
...ger_core_browser_features_password__features.cc | 6 +-
...ager_core_browser_features_password__features.h | 4 +-
...word__manager_core_browser_password__manager.cc | 6 +-
...anager_core_browser_password__manager__client.h | 4 +-
...er_core_common_password__manager__pref__names.h | 4 +-
...sions_prediction__service_prediction__common.cc | 6 +-
..._policy_core_browser_url__blocklist__manager.cc | 11 ++
...licy_core_common_cloud_cloud__policy__client.cc | 4 +-
...nents_policy_core_common_policy__pref__names.cc | 11 ++
...onents_policy_core_common_policy__pref__names.h | 11 ++
..._browser_realtime_url__lookup__service__base.cc | 4 +-
...nents_search__engines_template__url__service.cc | 4 +-
...mponents_signin_public_base_signin__switches.cc | 4 +-
...omponents_signin_public_base_signin__switches.h | 6 +-
...e_browser_supervised__user__metrics__service.cc | 6 +-
...r_core_browser_supervised__user__preferences.cc | 4 +-
.../patch-components_sync_service_sync__prefs.cc | 11 ++
...sted__vault_trusted__vault__connection__impl.cc | 4 +-
...isplay__embedder_skia__output__surface__impl.cc | 4 +-
...e_display__embedder_software__output__surface.h | 6 +-
...omponents_viz_service_display_skia__renderer.cc | 4 +-
...e__sinks_root__compositor__frame__sink__impl.cc | 4 +-
...components_viz_service_gl_gpu__service__impl.cc | 20 ++++
...-components_viz_service_gl_gpu__service__impl.h | 11 ++
.../patch-components_webui_flags_flags__state.cc | 4 +-
.../files/patch-content_app_content__main.cc | 6 +-
...atch-content_app_content__main__runner__impl.cc | 10 +-
www/chromium/files/patch-content_browser_BUILD.gn | 6 +-
...sibility_browser__accessibility__state__impl.cc | 4 +-
...owser__accessibility__state__impl__auralinux.cc | 8 +-
..._browser_browser__child__process__host__impl.cc | 6 +-
...tent_browser_child__process__launcher__helper.h | 11 --
...wser_child__process__launcher__helper__linux.cc | 4 +-
..._compositor_viz__process__transport__factory.cc | 4 +-
.../patch-content_browser_gpu_compositor__util.cc | 6 +-
...-content_browser_gpu_gpu__data__manager__impl.h | 4 +-
...rowser_gpu_gpu__data__manager__impl__private.cc | 6 +-
...browser_gpu_gpu__data__manager__impl__private.h | 6 +-
..._gpu_gpu__memory__buffer__manager__singleton.cc | 20 ----
...patch-content_browser_gpu_gpu__process__host.cc | 6 +-
...ent_browser_network__service__instance__impl.cc | 6 +-
...ia_service__video__capture__device__launcher.cc | 6 +-
...r_renderer__host_render__process__host__impl.cc | 14 +--
...er_renderer__host_render__process__host__impl.h | 16 +--
...der__process__host__impl__receiver__bindings.cc | 17 ++-
...wser_renderer__host_render__view__host__impl.cc | 4 +-
...browser_service__host_utility__process__host.cc | 26 ++---
...ser_service__host_utility__sandbox__delegate.cc | 24 +---
.../files/patch-content_common_features.cc | 4 +-
www/chromium/files/patch-content_common_features.h | 4 +-
www/chromium/files/patch-content_gpu_gpu__main.cc | 16 +--
...tent_public_browser_content__browser__client.cc | 4 +-
...atch-content_public_common_content__features.cc | 8 +-
.../patch-content_renderer_render__thread__impl.cc | 10 +-
...ent_renderer_renderer__blink__platform__impl.cc | 10 +-
...atch-content_shell_app_shell__main__delegate.cc | 4 +-
.../patch-content_shell_browser_shell__paths.cc | 20 ----
.../files/patch-content_utility_services.cc | 51 +--------
.../files/patch-content_utility_utility__main.cc | 40 +++----
.../patch-device_gamepad_gamepad__provider.cc | 4 +-
..._browser__context__keyed__service__factories.cc | 4 +-
...h-extensions_shell_app_shell__main__delegate.cc | 6 +-
...nd__buffer_client_fake__gpu__memory__buffer.cc} | 10 +-
...and__buffer_client_fake__gpu__memory__buffer.h} | 6 +-
...mand__buffer_service_dawn__context__provider.cc | 4 +-
..._command__buffer_service_gles2__cmd__decoder.cc | 4 +-
...e_shared__image_external__vk__image__backing.cc | 6 +-
..._image_external__vk__image__backing__factory.cc | 4 +-
...service_shared__image_shared__image__factory.cc | 4 +-
...service_shared__image_shared__image__manager.cc | 4 +-
...ommand__buffer_service_webgpu__decoder__impl.cc | 8 +-
...ffer_tests_gl__gpu__memory__buffer__unittest.cc | 6 +-
.../files/patch-gpu_config_gpu__control__list.cc | 4 +-
.../files/patch-gpu_ipc_service_gpu__init.cc | 20 ++--
.../files/patch-gpu_vulkan_vulkan__util.cc | 4 +-
...b_browser_headless__content__browser__client.cc | 6 +-
...ib_browser_headless__content__browser__client.h | 4 +-
www/chromium/files/patch-media_audio_BUILD.gn | 4 +-
...atch-media_audio_sndio_audio__manager__sndio.cc | 4 +-
...patch-media_audio_sndio_audio__manager__sndio.h | 4 +-
.../files/patch-media_base_media__switches.cc | 6 +-
.../files/patch-media_base_media__switches.h | 10 +-
.../files/patch-media_base_video__frame.cc | 8 +-
.../patch-media_ffmpeg_scripts_build__ffmpeg.py | 10 +-
...a_gpu_chromeos_platform__video__frame__utils.cc | 6 +-
.../patch-media_gpu_vaapi_vaapi__video__decoder.cc | 4 +-
www/chromium/files/patch-media_media__options.gni | 4 +-
www/chromium/files/patch-media_mojo_mojom_BUILD.gn | 4 +-
...media_mojo_mojom_video__frame__mojom__traits.cc | 10 +-
...ideo_gpu__memory__buffer__video__frame__pool.cc | 10 +-
.../files/patch-media_webrtc_audio__processor.cc | 4 +-
www/chromium/files/patch-mojo_core_BUILD.gn | 4 +-
www/chromium/files/patch-mojo_core_channel.cc | 4 +-
www/chromium/files/patch-net_BUILD.gn | 16 +--
www/chromium/files/patch-net_base_features.cc | 4 +-
.../files/patch-net_base_sockaddr__util__posix.cc | 4 +-
...net_disk__cache_simple_simple__file__tracker.cc | 4 +-
.../files/patch-net_http_http__network__session.cc | 4 +-
.../files/patch-net_socket_udp__socket__posix.cc | 6 +-
.../patch-net_socket_udp__socket__unittest.cc | 12 +-
.../files/patch-pdf_pdfium_pdfium__engine.cc | 6 +-
.../patch-printing_backend_cups__ipp__helper.cc | 4 +-
.../files/patch-printing_print__settings.h | 4 +-
.../files/patch-remoting_host_chromoting__host.cc | 4 +-
.../files/patch-remoting_host_host__main.cc | 12 +-
...t_it2me_it2me__native__messaging__host__main.cc | 30 ++++-
...st_remote__open__url_remote__open__url__main.cc | 20 ++++
.../patch-remoting_host_remoting__me2me__host.cc | 21 +++-
...st_security__key_remote__security__key__main.cc | 20 ++++
...t_setup_me2me__native__messaging__host__main.cc | 20 ++++
.../patch-remoting_host_setup_start__host__main.cc | 19 +++-
...bauthn_remote__webauthn__extension__notifier.cc | 6 +-
...emoting_host_webauthn_remote__webauthn__main.cc | 20 ++++
www/chromium/files/patch-sandbox_policy_BUILD.gn | 6 +-
...atch-sandbox_policy_openbsd_sandbox__openbsd.cc | 12 +-
.../files/patch-sandbox_policy_sandbox__type.cc | 53 +++++----
.../patch-services_device_public_mojom_BUILD.gn | 4 +-
...ces_device_serial_serial__device__enumerator.cc | 6 +-
...rvices_device_usb_usb__device__handle__usbfs.cc | 10 +-
.../patch-services_device_usb_usb__service.cc | 6 +-
www/chromium/files/patch-services_network_BUILD.gn | 4 +-
.../patch-services_network_network__context.cc | 6 +-
.../patch-services_network_network__context.h | 4 +-
.../patch-services_network_network__service.cc | 8 +-
.../patch-services_network_network__service.h | 6 +-
.../patch-services_network_public_cpp_BUILD.gn | 4 +-
.../patch-services_network_public_cpp_features.cc | 6 +-
.../patch-services_network_public_mojom_BUILD.gn | 4 +-
...ervices_on__device__model_pre__sandbox__init.cc | 28 ++---
...tch-services_screen__ai_public_cpp_utilities.cc | 12 +-
...h-services_tracing_public_cpp_trace__startup.cc | 11 ++
...h-third__party_blink_public_platform_platform.h | 4 +-
...blink_renderer_core_exported_web__view__impl.cc | 6 +-
...arty_blink_renderer_core_layout_layout__view.cc | 4 +-
...renderer_core_loader_mixed__content__checker.cc | 4 +-
...r_core_origin__trials_origin__trial__context.cc | 4 +-
...renderer_core_page_context__menu__controller.cc | 4 +-
...party_blink_renderer_core_paint_paint__layer.cc | 4 +-
...peerconnection_webrtc__audio__renderer__test.cc | 4 +-
...odules_webgl_webgl__rendering__context__base.cc | 4 +-
...renderer_modules_webgpu_gpu__canvas__context.cc | 4 +-
...ty_blink_renderer_platform_fonts_font__cache.cc | 4 +-
...rty_blink_renderer_platform_fonts_font__cache.h | 10 +-
...er_platform_graphics_video__frame__submitter.cc | 4 +-
...derer_platform_runtime__enabled__features.json5 | 18 +--
...nk_renderer_platform_scheduler_common_thread.cc | 8 +-
...arty_blink_renderer_platform_wtf_stack__util.cc | 10 +-
...-third__party_crashpad_crashpad_client_BUILD.gn | 4 +-
..._crashpad_crashpad_util_misc_capture__context.h | 9 +-
.../files/patch-third__party_ffmpeg_configure | 4 +-
...third__party_fontconfig_include_meson-config.h} | 27 ++---
...atch-third__party_fontconfig_src_src_fccompat.c | 8 +-
.../patch-third__party_node_check__version.py | 14 +++
.../files/patch-third__party_node_node.gni | 20 +---
..._party_pdfium_core_fxcodec_png_png__decoder.cpp | 13 ---
...arty_pdfium_core_fxge_linux_fx__linux__impl.cpp | 6 +-
...-third__party_sqlite_src_amalgamation_sqlite3.c | 6 +-
...rd__party_webrtc_modules_audio__device_BUILD.gn | 4 +-
...__capture_linux_x11_x__server__pixel__buffer.cc | 4 +-
.../patch-third__party_webrtc_rtc__base_network.cc | 6 +-
...ty_webrtc_rtc__base_physical__socket__server.cc | 18 +--
...h-third__party_webrtc_system__wrappers_BUILD.gn | 4 +-
.../patch-tools_protoc__wrapper_protoc__wrapper.py | 4 +-
...tch-ui_accessibility_accessibility__features.cc | 4 +-
...atch-ui_accessibility_accessibility__features.h | 4 +-
.../files/patch-ui_accessibility_ax__node.cc | 6 +-
.../files/patch-ui_accessibility_ax__tree.cc | 10 +-
.../files/patch-ui_accessibility_ax__tree.h | 8 +-
.../patch-ui_base_accelerators_accelerator.cc | 4 +-
...istener_global__accelerator__listener__ozone.cc | 12 +-
.../patch-ui_base_resource_resource__bundle.cc | 4 +-
.../files/patch-ui_base_ui__base__features.cc | 4 +-
.../files/patch-ui_base_ui__base__features.h | 4 +-
.../files/patch-ui_base_ui__base__switches.cc | 4 +-
.../files/patch-ui_base_ui__base__switches.h | 6 +-
.../files/patch-ui_base_webui_web__ui__util.cc | 6 +-
www/chromium/files/patch-ui_color_color__id.h | 4 +-
.../files/patch-ui_compositor_compositor.cc | 4 +-
...vents_devices_x11_device__data__manager__x11.cc | 4 +-
www/chromium/files/patch-ui_events_event.cc | 10 +-
www/chromium/files/patch-ui_gfx_BUILD.gn | 4 +-
www/chromium/files/patch-ui_gfx_gpu__extra__info.h | 11 ++
.../files/patch-ui_gfx_gpu__memory__buffer.cc | 15 ++-
.../files/patch-ui_gfx_gpu__memory__buffer.h | 32 ++++--
...x_mojom_native__handle__types__mojom__traits.cc | 4 +-
...fx_mojom_native__handle__types__mojom__traits.h | 4 +-
www/chromium/files/patch-ui_gfx_switches.cc | 8 +-
www/chromium/files/patch-ui_gfx_switches.h | 6 +-
www/chromium/files/patch-ui_gl_BUILD.gn | 20 +---
www/chromium/files/patch-ui_gl_gl__context.cc | 4 +-
.../files/patch-ui_gl_gl__implementation.cc | 4 +-
www/chromium/files/patch-ui_gl_gl__switches.cc | 22 ++--
.../files/patch-ui_gtk_ime__compat__check.cc | 21 ++++
.../patch-ui_gtk_printing_print__dialog__gtk.cc | 4 +-
.../files/patch-ui_ozone_common_egl__util.cc | 6 +-
...rm_headless_vulkan__implementation__headless.cc | 4 +-
..._ozone_platform_wayland_common_wayland__util.cc | 6 +-
.../patch-ui_ozone_platform_x11_x11__window.cc | 4 +-
.../patch-ui_views_controls_textfield_textfield.cc | 10 +-
.../patch-ui_views_controls_textfield_textfield.h | 4 +-
www/chromium/files/patch-ui_views_widget_widget.cc | 4 +-
www/chromium/files/patch-ui_views_widget_widget.h | 4 +-
.../patch-ui_views_window_dialog__delegate.cc | 4 +-
www/chromium/files/patch-v8_BUILD.gn | 12 +-
www/chromium/files/patch-v8_src_api_api.cc | 4 +-
.../patch-v8_src_base_platform_platform-posix.cc | 10 +-
.../files/patch-v8_src_execution_isolate.cc | 4 +-
.../files/patch-v8_src_libsampler_sampler.cc | 4 +-
...tch-v8_src_trap-handler_handler-inside-posix.cc | 6 +-
...wasm_baseline_ia32_liftoff-assembler-ia32-inl.h | 30 ++---
382 files changed, 1973 insertions(+), 1748 deletions(-)
diff --git a/www/chromium/Makefile b/www/chromium/Makefile
index 1017ff55f224..3fa5a1eeb9ed 100644
--- a/www/chromium/Makefile
+++ b/www/chromium/Makefile
@@ -1,6 +1,5 @@
PORTNAME= chromium
-PORTVERSION= 137.0.7151.119
-PORTREVISION= 1
+PORTVERSION= 138.0.7204.96
PULSEMV= 16
PULSEV= ${PULSEMV}.1
CATEGORIES= www wayland
diff --git a/www/chromium/distinfo b/www/chromium/distinfo
index 87c6b2edae3e..19705b90adc1 100644
--- a/www/chromium/distinfo
+++ b/www/chromium/distinfo
@@ -1,7 +1,7 @@
-TIMESTAMP = 1750318216
-SHA256 (chromium-137.0.7151.119.tar.xz) = 0deb4e0a63ff9bf1594c303781d67f55fa5b0bb35ab84bc71aef89ccd0b7e052
-SIZE (chromium-137.0.7151.119.tar.xz) = 7265398596
+TIMESTAMP = 1751436716
+SHA256 (chromium-138.0.7204.96.tar.xz) = bfc53392a6ba34241dab16aa954b045ceb6a0bc1273c36dedc2eaa068ec6d5ac
+SIZE (chromium-138.0.7204.96.tar.xz) = 7271479656
SHA256 (pulseaudio-16.1.tar.gz) = 027266c62f2a84422ac45fa721a649508f0f1628fb1fd9242315ac54ce2d7c92
SIZE (pulseaudio-16.1.tar.gz) = 2763111
-SHA256 (chromium-137.0.7151.119-testdata.tar.xz) = d55249334245e14538a8e220949f18a136efd9ba8031a79cccb23613fbd5d7e3
-SIZE (chromium-137.0.7151.119-testdata.tar.xz) = 656683112
+SHA256 (chromium-138.0.7204.96-testdata.tar.xz) = e9dbadb897f674ecc534657ff1f22bc29323f460e9485fde5513ad274e670abe
+SIZE (chromium-138.0.7204.96-testdata.tar.xz) = 922983984
diff --git a/www/chromium/files/patch-BUILD.gn b/www/chromium/files/patch-BUILD.gn
index 4c8afffd8420..54c68fcb2332 100644
--- a/www/chromium/files/patch-BUILD.gn
+++ b/www/chromium/files/patch-BUILD.gn
@@ -1,4 +1,4 @@
---- BUILD.gn.orig 2025-05-28 14:55:43 UTC
+--- BUILD.gn.orig 2025-07-02 06:08:04 UTC
+++ BUILD.gn
@@ -71,7 +71,7 @@ declare_args() {
root_extra_deps = []
@@ -17,7 +17,7 @@
"//net:net_unittests",
"//sandbox:sandbox_unittests",
"//services:services_unittests",
-@@ -449,7 +448,7 @@ group("gn_all") {
+@@ -448,7 +447,7 @@ group("gn_all") {
}
}
@@ -26,7 +26,7 @@
deps += [
"//third_party/breakpad:breakpad_unittests",
"//third_party/breakpad:core-2-minidump",
-@@ -636,6 +635,15 @@ group("gn_all") {
+@@ -635,6 +634,15 @@ group("gn_all") {
}
}
@@ -42,7 +42,7 @@
if (is_mac) {
deps += [
"//third_party/breakpad:dump_syms($host_system_allocator_toolchain)",
-@@ -684,7 +692,7 @@ group("gn_all") {
+@@ -683,7 +691,7 @@ group("gn_all") {
}
}
@@ -51,7 +51,7 @@
# The official builders use this binary from the default toolchain's
# output directory after building in order to upload the symbols of that
# binary. They build the binary like `ninja symupload` which requires the
-@@ -719,7 +727,7 @@ group("gn_all") {
+@@ -718,7 +726,7 @@ group("gn_all") {
]
}
@@ -60,7 +60,7 @@
deps += [
"//third_party/crashpad/crashpad:crashpad_tests",
"//third_party/crashpad/crashpad/handler:crashpad_handler",
-@@ -1128,7 +1136,7 @@ if (use_blink && !is_cronet_build) {
+@@ -1127,7 +1135,7 @@ if (use_blink && !is_cronet_build) {
"//third_party/blink/public:all_blink",
]
@@ -69,7 +69,7 @@
deps += [
":chrome_wpt_tests",
":headless_shell_wpt",
-@@ -1275,7 +1283,7 @@ if (use_blink && !is_cronet_build) {
+@@ -1274,7 +1282,7 @@ if (use_blink && !is_cronet_build) {
data_deps += [ "//content/web_test:web_test_common_mojom_js_data_deps" ]
}
@@ -78,7 +78,7 @@
# Using the default toolchain for this tool, as it's run during tests not
# during the build. This places a symlink in the root_build_dir for scrips
# to use.
-@@ -1289,7 +1297,7 @@ if (use_blink && !is_cronet_build) {
+@@ -1288,7 +1296,7 @@ if (use_blink && !is_cronet_build) {
data_deps += [ "//third_party/breakpad:dump_syms" ]
}
@@ -87,7 +87,7 @@
# Using the default toolchain for this tool, as it's run during tests not
# during the build. This places a symlink in the root_build_dir for scrips
# to use.
-@@ -1743,7 +1751,7 @@ group("chromium_builder_perf") {
+@@ -1742,7 +1750,7 @@ group("chromium_builder_perf") {
data_deps += [ "//chrome/test:performance_browser_tests" ]
}
diff --git a/www/chromium/files/patch-base_BUILD.gn b/www/chromium/files/patch-base_BUILD.gn
index 308a1337a216..8b460ebbffe1 100644
--- a/www/chromium/files/patch-base_BUILD.gn
+++ b/www/chromium/files/patch-base_BUILD.gn
@@ -1,6 +1,6 @@
---- base/BUILD.gn.orig 2025-05-28 14:55:43 UTC
+--- base/BUILD.gn.orig 2025-07-02 06:08:04 UTC
+++ base/BUILD.gn
-@@ -1108,11 +1108,26 @@ component("base") {
+@@ -1107,11 +1107,26 @@ component("base") {
# Needed for <atomic> if using newer C++ library than sysroot, except if
# building inside the cros_sdk environment - use host_toolchain as a
# more robust check for this.
@@ -28,7 +28,7 @@
if (use_allocator_shim) {
if (is_apple) {
sources += [ "allocator/early_zone_registration_apple.h" ]
-@@ -1132,7 +1147,7 @@ component("base") {
+@@ -1131,7 +1146,7 @@ component("base") {
# Allow more direct string conversions on platforms with native utf8
# strings
@@ -37,7 +37,7 @@
defines += [ "SYSTEM_NATIVE_UTF8" ]
}
-@@ -2166,6 +2181,22 @@ component("base") {
+@@ -2172,6 +2187,22 @@ component("base") {
]
}
@@ -60,7 +60,7 @@
# iOS
if (is_ios) {
sources += [
-@@ -2334,6 +2365,33 @@ component("base") {
+@@ -2340,6 +2371,33 @@ component("base") {
}
}
@@ -94,7 +94,7 @@
if (use_blink) {
sources += [
"files/file_path_watcher.cc",
-@@ -2729,7 +2787,7 @@ buildflag_header("protected_memory_buildflags") {
+@@ -2735,7 +2793,7 @@ buildflag_header("protected_memory_buildflags") {
header = "protected_memory_buildflags.h"
header_dir = "base/memory"
@@ -103,7 +103,7 @@
(is_win || is_linux || is_android || is_mac)
flags = [ "PROTECTED_MEMORY_ENABLED=$protected_memory_enabled" ]
-@@ -3236,7 +3294,7 @@ if (is_apple) {
+@@ -3242,7 +3300,7 @@ if (is_apple) {
}
}
@@ -112,7 +112,7 @@
# This test must compile with -fstack-protector-all
source_set("stack_canary_linux_unittests") {
testonly = true
-@@ -3924,7 +3982,7 @@ test("base_unittests") {
+@@ -3931,7 +3989,7 @@ test("base_unittests") {
]
}
@@ -121,7 +121,7 @@
sources += [
"debug/proc_maps_linux_unittest.cc",
"files/scoped_file_linux_unittest.cc",
-@@ -3952,7 +4010,7 @@ test("base_unittests") {
+@@ -3959,7 +4017,7 @@ test("base_unittests") {
"posix/file_descriptor_shuffle_unittest.cc",
"posix/unix_domain_socket_unittest.cc",
]
@@ -130,7 +130,7 @@
sources += [
"profiler/stack_base_address_posix_unittest.cc",
"profiler/stack_copier_signal_unittest.cc",
-@@ -3963,7 +4021,7 @@ test("base_unittests") {
+@@ -3970,7 +4028,7 @@ test("base_unittests") {
# Allow more direct string conversions on platforms with native utf8
# strings
@@ -139,7 +139,7 @@
defines += [ "SYSTEM_NATIVE_UTF8" ]
}
-@@ -4151,7 +4209,7 @@ test("base_unittests") {
+@@ -4158,7 +4216,7 @@ test("base_unittests") {
deps += [ ":base_profiler_test_support_library" ]
}
diff --git a/www/chromium/files/patch-base_allocator_partition__allocator_partition__alloc.gni b/www/chromium/files/patch-base_allocator_partition__allocator_partition__alloc.gni
index aad547d1c8cb..f279b52b32c6 100644
--- a/www/chromium/files/patch-base_allocator_partition__allocator_partition__alloc.gni
+++ b/www/chromium/files/patch-base_allocator_partition__allocator_partition__alloc.gni
@@ -1,4 +1,4 @@
---- base/allocator/partition_allocator/partition_alloc.gni.orig 2025-05-28 14:55:43 UTC
+--- base/allocator/partition_allocator/partition_alloc.gni.orig 2025-07-02 06:08:04 UTC
+++ base/allocator/partition_allocator/partition_alloc.gni
@@ -91,7 +91,7 @@ if (is_nacl) {
# TODO(crbug.com/329199197): Clean this up when experiments are complete.
@@ -9,7 +9,7 @@
!is_hwasan && (is_linux || is_android)
declare_args() {
-@@ -353,7 +353,7 @@ declare_args() {
+@@ -351,7 +351,7 @@ declare_args() {
declare_args() {
# Shadow metadata is still under development and only supports Linux
# for now.
@@ -18,7 +18,7 @@
}
declare_args() {
-@@ -496,7 +496,7 @@ assert(!use_asan_backup_ref_ptr || use_raw_ptr_hookabl
+@@ -494,7 +494,7 @@ assert(!use_asan_backup_ref_ptr || use_raw_ptr_hookabl
# dependencies that use partition_allocator are compiled in AOSP against a
# version of glibc that does not include pkeys syscall numbers.
is_pkeys_available =
diff --git a/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_BUILD.gn b/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_BUILD.gn
index 222d8f398001..4e4d827927f3 100644
--- a/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_BUILD.gn
+++ b/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_BUILD.gn
@@ -1,6 +1,6 @@
---- base/allocator/partition_allocator/src/partition_alloc/BUILD.gn.orig 2025-05-28 14:55:43 UTC
+--- base/allocator/partition_allocator/src/partition_alloc/BUILD.gn.orig 2025-07-02 06:08:04 UTC
+++ base/allocator/partition_allocator/src/partition_alloc/BUILD.gn
-@@ -893,7 +893,7 @@ if (is_clang_or_gcc) {
+@@ -892,7 +892,7 @@ if (is_clang_or_gcc) {
configs -= [ partition_alloc_enable_arc_config ]
}
}
diff --git a/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__base_debug_proc__maps__linux.cc b/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__base_debug_proc__maps__linux.cc
index c11438f7bcf6..f8aa0f73aaae 100644
--- a/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__base_debug_proc__maps__linux.cc
+++ b/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__base_debug_proc__maps__linux.cc
@@ -1,6 +1,6 @@
---- base/allocator/partition_allocator/src/partition_alloc/partition_alloc_base/debug/proc_maps_linux.cc.orig 2024-08-26 12:06:38 UTC
+--- base/allocator/partition_allocator/src/partition_alloc/partition_alloc_base/debug/proc_maps_linux.cc.orig 2025-07-02 06:08:04 UTC
+++ base/allocator/partition_allocator/src/partition_alloc/partition_alloc_base/debug/proc_maps_linux.cc
-@@ -19,7 +19,7 @@
+@@ -15,7 +15,7 @@
#include "partition_alloc/partition_alloc_check.h"
#if PA_BUILDFLAG(IS_LINUX) || PA_BUILDFLAG(IS_CHROMEOS) || \
diff --git a/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__config.h b/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__config.h
index dd242942fe84..e4cfcf24bd5c 100644
--- a/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__config.h
+++ b/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__config.h
@@ -1,6 +1,6 @@
---- base/allocator/partition_allocator/src/partition_alloc/partition_alloc_config.h.orig 2024-11-14 07:57:23 UTC
+--- base/allocator/partition_allocator/src/partition_alloc/partition_alloc_config.h.orig 2025-07-02 06:08:04 UTC
+++ base/allocator/partition_allocator/src/partition_alloc/partition_alloc_config.h
-@@ -170,7 +170,7 @@ constexpr bool kUseLazyCommit = false;
+@@ -164,7 +164,7 @@ constexpr bool kUseLazyCommit = false;
// This may be required on more platforms in the future.
#define PA_CONFIG_HAS_ATFORK_HANDLER() \
(PA_BUILDFLAG(IS_APPLE) || PA_BUILDFLAG(IS_LINUX) || \
@@ -9,7 +9,7 @@
// Enable shadow metadata.
//
-@@ -233,7 +233,7 @@ constexpr bool kUseLazyCommit = false;
+@@ -227,7 +227,7 @@ constexpr bool kUseLazyCommit = false;
// Also enabled on ARM64 macOS and iOS, as the 16kiB pages on this platform lead
// to larger slot spans.
#if PA_BUILDFLAG(IS_LINUX) || \
diff --git a/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__constants.h b/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__constants.h
index 4a78e527d576..870385c2cbc6 100644
--- a/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__constants.h
+++ b/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__constants.h
@@ -1,6 +1,6 @@
---- base/allocator/partition_allocator/src/partition_alloc/partition_alloc_constants.h.orig 2025-05-28 14:55:43 UTC
+--- base/allocator/partition_allocator/src/partition_alloc/partition_alloc_constants.h.orig 2025-07-02 06:08:04 UTC
+++ base/allocator/partition_allocator/src/partition_alloc/partition_alloc_constants.h
-@@ -312,7 +312,7 @@ PA_DEFINE_OPERATORS_FOR_FLAGS(PoolHandleMask);
+@@ -308,7 +308,7 @@ PA_DEFINE_OPERATORS_FOR_FLAGS(PoolHandleMask);
// 8GB for each of the glued pools).
#if PA_BUILDFLAG(HAS_64_BIT_POINTERS)
#if PA_BUILDFLAG(IS_ANDROID) || PA_BUILDFLAG(IS_IOS) || \
@@ -9,7 +9,7 @@
constexpr size_t kPoolMaxSize = 8 * kGiB;
#else
constexpr size_t kPoolMaxSize = 16 * kGiB;
-@@ -429,7 +429,7 @@ PA_ALWAYS_INLINE constexpr size_t MaxDirectMapped() {
+@@ -392,7 +392,7 @@ PA_ALWAYS_INLINE constexpr size_t MaxDirectMapped() {
// TODO(casey.smalley@arm.com): under 64k pages we can end up in a situation
// where a normal slot span will be large enough to contain multiple items,
// but the address will go over the final partition page after being aligned.
diff --git a/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__forward.h b/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__forward.h
index f6a75c332ad9..a643336a705f 100644
--- a/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__forward.h
+++ b/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__alloc__forward.h
@@ -1,16 +1,16 @@
---- base/allocator/partition_allocator/src/partition_alloc/partition_alloc_forward.h.orig 2023-12-10 06:10:27 UTC
+--- base/allocator/partition_allocator/src/partition_alloc/partition_alloc_forward.h.orig 2025-07-02 06:08:04 UTC
+++ base/allocator/partition_allocator/src/partition_alloc/partition_alloc_forward.h
-@@ -28,9 +28,13 @@ namespace internal {
+@@ -29,9 +29,13 @@ namespace internal {
// the second one 16. We could technically return something different for
// malloc() and operator new(), but this would complicate things, and most of
// our allocations are presumably coming from operator new() anyway.
+#if defined(__i386__) && defined(OS_FREEBSD)
+constexpr size_t kAlignment = 8;
+#else
- constexpr size_t kAlignment =
+ constexpr inline size_t kAlignment =
std::max(alignof(max_align_t),
static_cast<size_t>(__STDCPP_DEFAULT_NEW_ALIGNMENT__));
+#endif
+ static_assert(base::bits::HasSingleBit(kAlignment),
+ "Alignment must be power of two.");
static_assert(kAlignment <= 16,
- "PartitionAlloc doesn't support a fundamental alignment larger "
- "than 16 bytes.");
diff --git a/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__root.cc b/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__root.cc
index 9861082196a1..1516d9efd50d 100644
--- a/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__root.cc
+++ b/www/chromium/files/patch-base_allocator_partition__allocator_src_partition__alloc_partition__root.cc
@@ -1,4 +1,4 @@
---- base/allocator/partition_allocator/src/partition_alloc/partition_root.cc.orig 2025-05-28 14:55:43 UTC
+--- base/allocator/partition_allocator/src/partition_alloc/partition_root.cc.orig 2025-07-02 06:08:04 UTC
+++ base/allocator/partition_allocator/src/partition_alloc/partition_root.cc
@@ -45,7 +45,7 @@
#include "wow64apiset.h"
@@ -18,7 +18,7 @@
// When fork() is called, only the current thread continues to execute in the
// child process. If the lock is held, but *not* by this thread when fork() is
// called, we have a deadlock.
-@@ -1118,7 +1118,7 @@ void PartitionRoot::Init(PartitionOptions opts) {
+@@ -1110,7 +1110,7 @@ void PartitionRoot::Init(PartitionOptions opts) {
// apple OSes.
PA_CHECK((internal::SystemPageSize() == (size_t{1} << 12)) ||
(internal::SystemPageSize() == (size_t{1} << 14)));
diff --git a/www/chromium/files/patch-base_compiler__specific.h b/www/chromium/files/patch-base_compiler__specific.h
index 5ab44c84e57c..2b9c67c377df 100644
--- a/www/chromium/files/patch-base_compiler__specific.h
+++ b/www/chromium/files/patch-base_compiler__specific.h
@@ -1,6 +1,6 @@
---- base/compiler_specific.h.orig 2025-03-05 08:14:56 UTC
+--- base/compiler_specific.h.orig 2025-07-02 06:08:04 UTC
+++ base/compiler_specific.h
-@@ -729,6 +729,7 @@ inline constexpr bool AnalyzerAssumeTrue(bool arg) {
+@@ -733,6 +733,7 @@ inline constexpr bool AnalyzerAssumeTrue(bool arg) {
#if __has_cpp_attribute(clang::preserve_most) && \
(defined(ARCH_CPU_ARM64) || defined(ARCH_CPU_X86_64)) && \
!defined(COMPONENT_BUILD) && \
diff --git a/www/chromium/files/patch-base_debug_debugger__posix.cc b/www/chromium/files/patch-base_debug_debugger__posix.cc
index 9da4c4c38225..b91499e6710a 100644
--- a/www/chromium/files/patch-base_debug_debugger__posix.cc
+++ b/www/chromium/files/patch-base_debug_debugger__posix.cc
@@ -1,6 +1,6 @@
---- base/debug/debugger_posix.cc.orig 2025-05-28 14:55:43 UTC
+--- base/debug/debugger_posix.cc.orig 2025-07-02 06:08:04 UTC
+++ base/debug/debugger_posix.cc
-@@ -42,6 +42,10 @@
+@@ -38,6 +38,10 @@
#include <sys/sysctl.h>
#endif
@@ -11,7 +11,7 @@
#if BUILDFLAG(IS_FREEBSD)
#include <sys/user.h>
#endif
-@@ -100,33 +104,52 @@ bool BeingDebugged() {
+@@ -96,33 +100,52 @@ bool BeingDebugged() {
// Caution: struct kinfo_proc is marked __APPLE_API_UNSTABLE. The source and
// binary interfaces may change.
diff --git a/www/chromium/files/patch-base_memory_platform__shared__memory__region.h b/www/chromium/files/patch-base_memory_platform__shared__memory__region.h
index 9270f19cc874..5b98ac1a8aca 100644
--- a/www/chromium/files/patch-base_memory_platform__shared__memory__region.h
+++ b/www/chromium/files/patch-base_memory_platform__shared__memory__region.h
@@ -1,6 +1,6 @@
---- base/memory/platform_shared_memory_region.h.orig 2025-05-28 14:55:43 UTC
+--- base/memory/platform_shared_memory_region.h.orig 2025-07-02 06:08:04 UTC
+++ base/memory/platform_shared_memory_region.h
-@@ -18,7 +18,7 @@
+@@ -19,7 +19,7 @@
#include "base/unguessable_token.h"
#include "build/build_config.h"
@@ -9,7 +9,7 @@
namespace content {
class SandboxIPCHandler;
}
-@@ -85,7 +85,7 @@ class BASE_EXPORT PlatformSharedMemoryRegion {
+@@ -86,7 +86,7 @@ class BASE_EXPORT PlatformSharedMemoryRegion {
kMaxValue = GET_SHMEM_TEMP_DIR_FAILURE
};
@@ -18,16 +18,7 @@
// Structure to limit access to executable region creation.
struct ExecutableRegion {
private:
-@@ -217,7 +217,7 @@ class BASE_EXPORT PlatformSharedMemoryRegion {
- CheckPlatformHandlePermissionsCorrespondToMode);
- static PlatformSharedMemoryRegion Create(Mode mode,
- size_t size
--#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)
-+#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_BSD)
- ,
- bool executable = false
- #endif
-@@ -236,7 +236,7 @@ class BASE_EXPORT PlatformSharedMemoryRegion {
+@@ -125,7 +125,7 @@ class BASE_EXPORT PlatformSharedMemoryRegion {
#if BUILDFLAG(IS_FUCHSIA)
kNotVmo,
#endif
@@ -36,3 +27,12 @@
kFcntlFailed,
kReadOnlyFdNotReadOnly,
kUnexpectedReadOnlyFd,
+@@ -256,7 +256,7 @@ class BASE_EXPORT PlatformSharedMemoryRegion {
+ CheckPlatformHandlePermissionsCorrespondToMode);
+ static PlatformSharedMemoryRegion Create(Mode mode,
+ size_t size
+-#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS)
++#if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_BSD)
+ ,
+ bool executable = false
+ #endif
diff --git a/www/chromium/files/patch-base_memory_platform__shared__memory__region__posix.cc b/www/chromium/files/patch-base_memory_platform__shared__memory__region__posix.cc
index dd4328869bb7..9b0d02ebffa8 100644
--- a/www/chromium/files/patch-base_memory_platform__shared__memory__region__posix.cc
+++ b/www/chromium/files/patch-base_memory_platform__shared__memory__region__posix.cc
@@ -1,4 +1,4 @@
---- base/memory/platform_shared_memory_region_posix.cc.orig 2025-05-28 14:55:43 UTC
+--- base/memory/platform_shared_memory_region_posix.cc.orig 2025-07-02 06:08:04 UTC
+++ base/memory/platform_shared_memory_region_posix.cc
@@ -61,7 +61,7 @@ std::optional<FDAccessModeError> CheckFDAccessMode(int
@@ -9,7 +9,7 @@
// static
ScopedFD PlatformSharedMemoryRegion::ExecutableRegion::CreateFD(size_t size) {
PlatformSharedMemoryRegion region =
-@@ -183,7 +183,7 @@ bool PlatformSharedMemoryRegion::ConvertToUnsafe() {
+@@ -186,7 +186,7 @@ bool PlatformSharedMemoryRegion::ConvertToUnsafe() {
// static
PlatformSharedMemoryRegion PlatformSharedMemoryRegion::Create(Mode mode,
size_t size
@@ -18,7 +18,7 @@
,
bool executable
#endif
-@@ -212,7 +212,7 @@ PlatformSharedMemoryRegion PlatformSharedMemoryRegion:
+@@ -215,7 +215,7 @@ PlatformSharedMemoryRegion PlatformSharedMemoryRegion:
// flag.
FilePath directory;
if (!GetShmemTempDir(
diff --git a/www/chromium/files/patch-base_process_internal__linux.h b/www/chromium/files/patch-base_process_internal__linux.h
index 8d8e4f284eac..fa154978ba86 100644
--- a/www/chromium/files/patch-base_process_internal__linux.h
+++ b/www/chromium/files/patch-base_process_internal__linux.h
@@ -1,6 +1,6 @@
---- base/process/internal_linux.h.orig 2025-04-04 08:52:13 UTC
+--- base/process/internal_linux.h.orig 2025-07-02 06:08:04 UTC
+++ base/process/internal_linux.h
-@@ -144,6 +144,9 @@ TimeDelta ClockTicksToTimeDelta(int64_t clock_ticks);
+@@ -146,6 +146,9 @@ TimeDelta ClockTicksToTimeDelta(int64_t clock_ticks);
// arguments to the lambda.
template <typename Lambda>
void ForEachProcessTask(base::ProcessHandle process, Lambda&& lambda) {
@@ -10,7 +10,7 @@
// Iterate through the different threads tracked in /proc/<pid>/task.
FilePath fd_path = GetProcPidDir(process).Append("task");
-@@ -167,6 +170,7 @@ void ForEachProcessTask(base::ProcessHandle process, L
+@@ -169,6 +172,7 @@ void ForEachProcessTask(base::ProcessHandle process, L
FilePath task_path = fd_path.Append(tid_str);
lambda(tid, task_path);
}
diff --git a/www/chromium/files/patch-base_process_process__posix.cc b/www/chromium/files/patch-base_process_process__posix.cc
index 877dca1522a6..7f022ca00cbb 100644
--- a/www/chromium/files/patch-base_process_process__posix.cc
+++ b/www/chromium/files/patch-base_process_process__posix.cc
@@ -1,6 +1,6 @@
---- base/process/process_posix.cc.orig 2025-02-19 07:43:18 UTC
+--- base/process/process_posix.cc.orig 2025-07-02 06:08:04 UTC
+++ base/process/process_posix.cc
-@@ -23,10 +23,15 @@
+@@ -25,10 +25,15 @@
#include "base/trace_event/base_tracing.h"
#include "build/build_config.h"
@@ -17,7 +17,7 @@
#if BUILDFLAG(CLANG_PROFILING)
#include "base/test/clang_profiling.h"
#endif
-@@ -100,7 +105,7 @@ bool WaitpidWithTimeout(base::ProcessHandle handle,
+@@ -104,7 +109,7 @@ bool WaitpidWithTimeout(base::ProcessHandle handle,
}
#endif
@@ -26,7 +26,7 @@
// Using kqueue on Mac so that we can wait on non-child processes.
// We can't use kqueues on child processes because we need to reap
// our own children using wait.
-@@ -379,7 +384,7 @@ bool Process::WaitForExitWithTimeoutImpl(base::Process
+@@ -387,7 +392,7 @@ bool Process::WaitForExitWithTimeoutImpl(base::Process
const bool exited = (parent_pid < 0);
if (!exited && parent_pid != our_pid) {
@@ -35,7 +35,7 @@
// On Mac we can wait on non child processes.
return WaitForSingleNonChildProcess(handle, timeout);
#else
-@@ -416,7 +421,56 @@ void Process::Exited(int exit_code) const {
+@@ -424,7 +429,56 @@ void Process::Exited(int exit_code) const {
int Process::GetOSPriority() const {
DCHECK(IsValid());
diff --git a/www/chromium/files/patch-base_threading_platform__thread__unittest.cc b/www/chromium/files/patch-base_threading_platform__thread__unittest.cc
index 6544f36c25d9..f0791854a0e8 100644
--- a/www/chromium/files/patch-base_threading_platform__thread__unittest.cc
+++ b/www/chromium/files/patch-base_threading_platform__thread__unittest.cc
@@ -1,4 +1,4 @@
---- base/threading/platform_thread_unittest.cc.orig 2025-04-04 08:52:13 UTC
+--- base/threading/platform_thread_unittest.cc.orig 2025-07-02 06:08:04 UTC
+++ base/threading/platform_thread_unittest.cc
@@ -36,7 +36,7 @@
#include "base/time/time.h"
@@ -9,7 +9,7 @@
#include <pthread.h>
#include <sys/syscall.h>
#include <sys/types.h>
-@@ -370,7 +370,7 @@ TEST(PlatformThreadTest,
+@@ -369,7 +369,7 @@ TEST(PlatformThreadTest,
// and hardcodes what we know. Please inform scheduler-dev@chromium.org if this
// proprerty changes for a given platform.
TEST(PlatformThreadTest, CanChangeThreadType) {
@@ -18,16 +18,7 @@
// On Ubuntu, RLIMIT_NICE and RLIMIT_RTPRIO are 0 by default, so we won't be
// able to increase priority to any level unless we are root (euid == 0).
bool kCanIncreasePriority = false;
-@@ -435,7 +435,7 @@ TEST(PlatformThreadTest, SetCurrentThreadTypeTest) {
- #if BUILDFLAG(IS_APPLE)
- TestPriorityResultingFromThreadType(ThreadType::kResourceEfficient,
- ThreadPriorityForTest::kUtility);
--#elif BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_LINUX)
-+#elif BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_BSD)
- TestPriorityResultingFromThreadType(
- ThreadType::kResourceEfficient,
- ThreadPriorityForTest::kResourceEfficient);
-@@ -624,12 +624,16 @@ INSTANTIATE_TEST_SUITE_P(
+@@ -606,12 +606,16 @@ INSTANTIATE_TEST_SUITE_P(
#endif // BUILDFLAG(IS_APPLE)
diff --git a/www/chromium/files/patch-base_trace__event_malloc__dump__provider.cc b/www/chromium/files/patch-base_trace__event_malloc__dump__provider.cc
index 5b3e4277da06..d16f0a13265a 100644
--- a/www/chromium/files/patch-base_trace__event_malloc__dump__provider.cc
+++ b/www/chromium/files/patch-base_trace__event_malloc__dump__provider.cc
@@ -1,4 +1,4 @@
---- base/trace_event/malloc_dump_provider.cc.orig 2025-03-05 08:14:56 UTC
+--- base/trace_event/malloc_dump_provider.cc.orig 2025-07-02 06:08:04 UTC
+++ base/trace_event/malloc_dump_provider.cc
@@ -31,6 +31,8 @@
@@ -18,7 +18,7 @@
void ReportMallinfoStats(ProcessMemoryDump* pmd,
size_t* total_virtual_size,
size_t* resident_size,
-@@ -370,6 +372,9 @@ bool MallocDumpProvider::OnMemoryDump(const MemoryDump
+@@ -367,6 +369,9 @@ bool MallocDumpProvider::OnMemoryDump(const MemoryDump
&allocated_objects_count);
#elif BUILDFLAG(IS_FUCHSIA)
// TODO(fuchsia): Port, see https://crbug.com/706592.
diff --git a/www/chromium/files/patch-build_config_BUILDCONFIG.gn b/www/chromium/files/patch-build_config_BUILDCONFIG.gn
index b0ec51d03b3a..3749850480a4 100644
--- a/www/chromium/files/patch-build_config_BUILDCONFIG.gn
+++ b/www/chromium/files/patch-build_config_BUILDCONFIG.gn
@@ -1,4 +1,4 @@
*** 10959 LINES SKIPPED ***